@@ -12,21 +12,17 @@ my %cap_opts;
 sub init_edit_disp_capture {
     &set_pointer($gui{dialogEdit}, 'watch');
     my $cap_optstr = IRecordingScreenSettings_getOptions($vmc{IRecordingScreenSettings});
+    undef(%cap_opts); # We must clear the hash each time as old options from a pervious edit might get left
 
-    # We must clear the hash each time as old options from a pervious edit might get left
-    undef(%cap_opts);
-
-    # VB has implied defaults for options that are NOT explicit. We'll make them explicit here for easier processing.
-    # they will be overwritten by the parsing engine if specified.
+    # VB has implied defaults for options that are NOT explicit. We'll make them
+    # explicit here for easier processing. they will be overwritten by the parsing
+    # engine if specified.
     $cap_opts{ac_enabled}='false';
     $cap_opts{vc_enabled}='true';
     $cap_opts{ac_profile}='med';
-
-    # Process the options into a hash and set some defaults for easy use later
     $cap_optstr =~ s/ //g; # Get rid of stray spaces
 
-    # Fill the hash with the options
-    foreach my $opt (split(',', $cap_optstr)) {
+    foreach my $opt (split(',', $cap_optstr)) { # Fill the hash with the options.
         my ($l, $r) = split('=', $opt);
         $cap_opts{$l}=$r;
     }
@@ -42,16 +38,12 @@ sub init_edit_disp_capture {
     else  { $gui{comboboxEditDispCaptureMode}->set_active(0); }
 
     &combobox_set_active_text($gui{comboboxEditDispAudioQuality}, $cap_opts{ac_profile}, 0);
-
-    my $w = IRecordingScreenSettings_getVideoWidth($vmc{IRecordingScreenSettings});
-    my $h = IRecordingScreenSettings_getVideoHeight($vmc{IRecordingScreenSettings});
-
-    # Set the framesize combobox to the active position depending on associated spinboxes
-    my $fsiter = $gui{liststoreDispCaptureSize}->get_iter_first();
+    my ($w, $h) = (IRecordingScreenSettings_getVideoWidth($vmc{IRecordingScreenSettings}), IRecordingScreenSettings_getVideoHeight($vmc{IRecordingScreenSettings}));
+    my $fsiter = $gui{liststoreDispCaptureSize}->get_iter_first(); # Set the framesize combobox to the active position depending on associated spinboxes
     my $fspos = 0;
     $gui{comboboxEditDispCaptureSize}->set_active(0);
 
-    while ($gui{liststoreDispCaptureSize}->iter_is_valid($fsiter)) {
+    while (defined($fsiter) and $gui{liststoreDispCaptureSize}->iter_is_valid($fsiter)) {
         if ($w == $gui{liststoreDispCaptureSize}->get_value($fsiter, 1) and $h == $gui{liststoreDispCaptureSize}->get_value($fsiter, 2)) {
             $gui{comboboxEditDispCaptureSize}->set_active($fspos);
             last;
@@ -113,8 +105,7 @@ sub disp_toggleCapture {
     my $state = $gui{checkbuttonEditDispCapture}->get_active();
     IRecordingSettings_setEnabled($vmc{IRecordingSettings}, $state); # Set the master recording setting
     IRecordingScreenSettings_setEnabled($vmc{IRecordingScreenSettings}, $state); # Set it specific to screen 0. We only support screen 0 at the moment
-    # Don't enable other widgets unless in WriteLock Mode
-    $gui{tableEditDispCapture}->set_sensitive($state) if ($vmc{SessionType} eq 'WriteLock');
+    $gui{tableEditDispCapture}->set_sensitive($state) if ($vmc{SessionType} eq 'WriteLock'); # Don't enable other widgets unless in WriteLock Mode
 }
 
 # If the combobox changes, update the associated spinboxes
@@ -154,8 +145,7 @@ sub disp_cap_send_opts {
 
     foreach my $key (keys(%cap_opts)) { $cap_optstr .= sprintf('%s=%s,', $key, $cap_opts{$key}); }
 
-    # Doesn't seem strict, but JIC strip trailing ,
-    chop($cap_optstr);
+    chop($cap_optstr); # VM doesn't seem strict, but JIC strip trailing ,
     IRecordingScreenSettings_setOptions($vmc{IRecordingScreenSettings}, $cap_optstr) if ($vmc{SessionType} eq 'WriteLock');
 }
 
