@@ -4,9 +4,9 @@ use warnings;
 our (%gui, %vmc);
 
 sub init_edit_gen_description {
-    &busy_pointer($gui{dialogEdit}, 1);
+    &set_pointer($gui{dialogEdit}, 'watch');
     $gui{textbufferEditGenDescription}->set_text(IMachine_getDescription($vmc{IMachine}));
-    &busy_pointer($gui{dialogEdit}, 0);
+    &set_pointer($gui{dialogEdit});
 }
 
 # Sets the guest's description
