@@ -155,7 +155,7 @@ sub show_dialog_createfloppy {
                     # We are being called from the Edit Storage Dialog
                     &storage_attach_floppy(undef, $IMedium) if ($IMedium);
                     IMachine_saveSettings($vmc{IMachine});
-                    &addrow_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
+                    &addrow_msg_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
                 }
             }
         }
@@ -216,7 +216,7 @@ sub show_dialog_createhd {
                     # We are being called from the Edit Storage Dialog
                     &storage_attach_hd(undef, $IMedium) if ($IMedium);
                     IMachine_saveSettings($vmc{IMachine});
-                    &addrow_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
+                    &addrow_msg_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
                 }
             }
         }
@@ -294,7 +294,7 @@ sub storage_attach_hd {
     if (!$attached) { &show_err_msg('ctrfull'); }
 
     IMachine_saveSettings($vmc{IMachine});
-    &addrow_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
+    &addrow_msg_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
     &fill_list_editstorage($vmc{IMachine});
 }
 
@@ -319,7 +319,7 @@ sub storage_attach_dvd {
     }
 
     IMachine_saveSettings($vmc{IMachine});
-    &addrow_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
+    &addrow_msg_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
     &fill_list_editstorage($vmc{IMachine});
 }
 
@@ -343,7 +343,7 @@ sub storage_attach_floppy {
     }
 
     IMachine_saveSettings($vmc{IMachine});
-    &addrow_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
+    &addrow_msg_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
     &fill_list_editstorage($vmc{IMachine});
 }
 
@@ -471,7 +471,7 @@ sub storage_connected_port {
             IMachine_detachDevice($vmc{IMachine}, $$storref{ControllerName}, $$storref{Port}, $$storref{Device});
             IMachine_attachDevice($vmc{IMachine}, $$storref{ControllerName}, $newport, $newdevice, $$storref{MediumType}, $$storref{IMedium});
             IMachine_saveSettings($vmc{IMachine});
-            &addrow_log("Settings explicitly saved for $vmc{Name} due to storage attachment");
+            &addrow_msg_log("Settings explicitly saved for $vmc{Name} due to storage attachment");
             &fill_list_editstorage($vmc{IMachine});
         }
     }
