@@ -4,11 +4,11 @@ use warnings;
 our (%gui, %vmc);
 
 sub init_edit_sys_accel {
-    &busy_pointer($gui{dialogEdit}, 1);
+    &set_pointer($gui{dialogEdit}, 'watch');
     $gui{checkbuttonEditSysNested}->set_active(&bl(IMachine_getHWVirtExProperty($vmc{IMachine}, 'NestedPaging')));
     $gui{checkbuttonEditSysVPID}->set_active(&bl(IMachine_getHWVirtExProperty($vmc{IMachine}, 'VPID')));
     &combobox_set_active_text($gui{comboboxEditSysParavirt}, IMachine_getParavirtProvider($vmc{IMachine}), 0);
-    &busy_pointer($gui{dialogEdit}, 0);
+    &set_pointer($gui{dialogEdit});
 }
 
 # Sets the paravirtualization interface
