@@ -89,21 +89,21 @@ sub sys_mother_chipset { if ($vmc{SessionType} eq 'WriteLock') { IMachine_setChi
 # Moves the boot device to a higher priority
 sub sys_mother_boot_dev_up {
     if ($vmc{SessionType} eq 'WriteLock') {
-        my ($liststore, $iter) = $gui{treeviewEditSysBoot}->get_selection->get_selected;
+        my ($liststore, $iter) = $gui{treeviewEditSysBoot}->get_selection->get_selected();
         my $path = $liststore->get_path($iter);
         $path->prev; # Modifies path directly
         my $iter_prev = $liststore->get_iter($path);
-        $liststore->move_before($iter, $iter_prev) if ($liststore->iter_is_valid($iter_prev));
+        $liststore->move_before($iter, $iter_prev) if (defined($iter_prev) and $liststore->iter_is_valid($iter_prev));
     }
 }
 
 # Moves the boot device to a lower priority
 sub sys_mother_boot_dev_down {
     if ($vmc{SessionType} eq 'WriteLock') {
-        my ($liststore, $iter) = $gui{treeviewEditSysBoot}->get_selection->get_selected;
-        my (undef, $iter_next) = $gui{treeviewEditSysBoot}->get_selection->get_selected;
+        my ($liststore, $iter) = $gui{treeviewEditSysBoot}->get_selection->get_selected();
+        my (undef, $iter_next) = $gui{treeviewEditSysBoot}->get_selection->get_selected();
         $liststore->iter_next($iter_next); # Modifies the iter directly - hence the above call twice
-        $liststore->move_after($iter, $iter_next) if ($liststore->iter_is_valid($iter_next));
+        $liststore->move_after($iter, $iter_next) if (defined($iter_next) and $liststore->iter_is_valid($iter_next));
     }
 }
 
@@ -112,7 +112,7 @@ sub sys_mother_boot_order {
     my $iter = $liststore->get_iter_first();
     my $i = 1;
 
-    while ($liststore->iter_is_valid($iter)) {
+    while (defined($iter) and $liststore->iter_is_valid($iter)) {
         my $dev = $liststore->get($iter, 1);
         $dev = 'Null' if ($liststore->get($iter, 0) == 0);
         IMachine_setBootOrder($vmc{IMachine}, $i, $dev);
