@@ -69,8 +69,8 @@ our (%gui);
                 noextensions       => ['VirtualBox Extension Pack',
                                        'This server does not have the Oracle VirtualBox Extension Pack or VNC Extension Pack installed. ' .
                                        'You should install the Oracle Extension Pack if available for your OS, otherwise ' .
-                                       "install the VNC extension pack." .
-                                       '    See URL: http://www.virtualbox.org/wiki/Downloads',
+                                       'install the VNC extension pack.' .
+                                       '    See URL: https://www.virtualbox.org/wiki/Downloads',
                                        'warning'],
                 noscreenshot       => ['Screenshot Failed',
                                        'Guest is not in a state suitable for screenshots or your' .
@@ -86,12 +86,12 @@ our (%gui);
                                        'Guest has an existing session. Either through RemoteBox or another program.' .
                                        ' Please close that session and try again.',
                                        'error'],
-                logempty           => ['Guest Log Empty',
-                                       'This guest log cannot be saved as it does not exist yet or is empty',
-                                       'warning'],
-                logsavefailed      => ['Cannot Save Guest Log',
+                guestlogsave       => ['Cannot Save Guest Log',
                                        'An attempt to save the guest log failed',
                                        'error'],
+                msglogsave         => ['Cannot Save Message Log',
+                                        'An attempt to save the message log failed',
+                                       'error'],
                 settings           => ['Cannot Edit Settings',
                                        'Guest settings cannot be changed as the guest is locked by another process',
                                        'error'],
@@ -134,7 +134,7 @@ our (%gui);
         my ($title, $body, $type) = @{ $err{$key} };
         $dialog = $gui{messagedialogWarning} if ($type eq 'warning');
         $body .= "\n$append" if ($append);
-        &addrow_log("Error Dialog:    $title:    $body");
+        &addrow_msg_log("Error Dialog:    $title:    $body");
         $dialog->set_markup("<big><b>$title</b></big>");
         $dialog->set_title($title);
         # Filter out <> to avoid them being treated as markup
@@ -152,7 +152,7 @@ sub show_invalid_object_msg {
                'the connection may be in an unknown state. Disconnecting will try to recover ' .
                "but will require you to reconnect.\n\nAdditional:\n";
     $body .= $append if ($append);
-    &addrow_log("Error Dialog:    Invalid Object Reference:    $body");
+    &addrow_msg_log("Error Dialog:    Invalid Object Reference:    $body");
     $gui{messagedialogInvalidObject}->format_secondary_markup($body);
 
     my $response = $gui{messagedialogInvalidObject}->run;
