@@ -21,18 +21,9 @@ our (%gui, $sharedir);
         my $ISystemProperties = IVirtualBox_getSystemProperties($gui{websn});
         %vhost = (ISystemProperties => $ISystemProperties,
                   IHost             => $IHost,
-                  vbver             => IVirtualBox_getVersion($gui{websn}),
-                  buildrev          => IVirtualBox_getRevision($gui{websn}),
-                  pkgtype           => IVirtualBox_getPackageType($gui{websn}),
-                  settingsfile      => IVirtualBox_getSettingsFilePath($gui{websn}),
                   os                => IHost_getOperatingSystem($IHost),
-                  osver             => IHost_getOSVersion($IHost),
                   maxhostcpuon      => IHost_getProcessorOnlineCount($IHost),
-                  cpudesc           => IHost_getProcessorDescription($IHost),
-                  cpuspeed          => IHost_getProcessorSpeed($IHost),
                   memsize           => IHost_getMemorySize($IHost),
-                  pae               => IHost_getProcessorFeature($IHost, 'PAE'),
-                  vtx               => IHost_getProcessorFeature($IHost, 'HWVirtEx'),
                   machinedir        => ISystemProperties_getDefaultMachineFolder($ISystemProperties),
                   minhdsize         => 4096, # Not returnable by API but VB itself uses this value
                   minhdsizemb       => 4, # Not returnable by API but VB itself uses this value
@@ -51,7 +42,6 @@ our (%gui, $sharedir);
                   vrdeextpack       => ISystemProperties_getDefaultVRDEExtPack($ISystemProperties),
                   vrdelib           => ISystemProperties_getVRDEAuthLibrary($ISystemProperties),
                   additionsiso      => ISystemProperties_getDefaultAdditionsISO($ISystemProperties),
-                  defaudio          => ISystemProperties_getDefaultAudioDriver($ISystemProperties),
                   hwexclusive       => ISystemProperties_getExclusiveHwVirt($ISystemProperties),
                   autostartdb       => ISystemProperties_getAutostartDatabasePath($ISystemProperties));
 
