@@ -143,6 +143,7 @@ our %signal = (fam                => $gui{comboboxNewOSFam}->signal_connect(chan
                usbtoggle          => $gui{checkbuttonEditUSBEnable}->signal_connect(toggled => \&usb_toggle),
                snapfolderactivate => $gui{entryEditGenSnapFolder}->signal_connect(activate => \&gen_snapfolder),
                snapfolderfocus    => $gui{entryEditGenSnapFolder}->signal_connect(activate => \&gen_snapfolder),
+
                treeviewGuest_cursorChanged => $gui{treeviewGuest}->signal_connect('cursor-changed' => \&onsel_list_guest),
                treeviewSnapshots_cursorChanged => $gui{treeviewSnapshots}->signal_connect('cursor-changed' => \&onsel_list_snapshots),
                treeviewPFRulesIPv4_cursorChanged => $gui{treeviewPFRulesIPv4}->signal_connect('cursor-changed' => \&onsel_list_pf4),
@@ -356,10 +357,10 @@ sub handle_vboxfilechooser {
         my $IMachine = IVirtualBox_openMachine($gui{websn}, $vboxfile);
         if ($IMachine) {
             IVirtualBox_registerMachine($gui{websn}, $IMachine);
-            &addrow_log("Imported guest from $vboxfile");
+            &addrow_msg_log("Imported guest from $vboxfile");
             &fill_list_guest();
         }
-        else { &addrow_log("Failed to import guest from $vboxfile"); }
+        else { &addrow_msg_log("Failed to import guest from $vboxfile"); }
     }
 }
 
