@@ -7,24 +7,21 @@ our (%gui, %vmc, %signal, %prefs);
 {
     sub expand_details_row {
         my ($treeview, $treeiter, $treepath) = @_;
-        my $model = $treeview->get_model();
-        my @row = $model->get($treeiter);
+        my @row = $gui{treestoreDetails}->get($treeiter);
         $prefs{$row[5]} = 1;
     }
 
     sub collapse_details_row {
         my ($treeview, $treeiter, $treepath) = @_;
-        my $model = $treeview->get_model();
-        my @row = $model->get($treeiter);
+        my @row = $gui{treestoreDetails}->get($treeiter);
         $prefs{$row[5]} = 0;
     }
 
     # Fill a brief version of the guest details
     sub fill_list_details_brief {
-        &addrow_log("Fetching guest details...");
-        $gui{treestoreDetails}->clear();
-        my $treemodel = $gui{treeviewDetails}->get_model();
         my $gref = &getsel_list_guest();
+        &addrow_msg_log("Retrieving guest details for $$gref{Name}");
+        $gui{treestoreDetails}->clear();
         my $IGraphicsAdapter = IMachine_getGraphicsAdapter($$gref{IMachine});
         my $iter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatGen}, 'Guest Summary', 800, 0.0, 'EXPANDDETGEN']);
         &addrow_details($iter, [1, 2], [' Name:', $$gref{Name}]);
@@ -33,22 +30,20 @@ our (%gui, %vmc, %signal, %prefs);
         $mem = ($mem > 1023) ? sprintf("%.2f GB", $mem / 1024) : "$mem MB";
         &addrow_details($iter, [1, 2], [' Base Memory:', $mem]);
         &addrow_details($iter, [1, 2], [' Video Memory:', IGraphicsAdapter_getVRAMSize($IGraphicsAdapter) . ' MB']);
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($iter), 1) if ($prefs{EXPANDDETGEN});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($iter), 1) if ($prefs{EXPANDDETGEN});
         my $desciter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatDesc}, 'Description', 800, 0.0, 'EXPANDDETDESC']);
         my $desc = IMachine_getDescription($$gref{IMachine});
-        $desc ? &addrow_details($desciter, [1, 2], [' Description:', $desc])
-            : &addrow_details($desciter, [1], [' <None>']);
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($desciter), 1) if ($prefs{EXPANDDETDESC});
-        &addrow_log("Guest details retrieved.");
+        $desc ? &addrow_details($desciter, [1, 2], [' Description:', $desc]) : &addrow_details($desciter, [1], [' <None>']);
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($desciter), 1) if ($prefs{EXPANDDETDESC});
+        &addrow_msg_log("Guest details retrieved for $$gref{Name}");
     }
 
     # Fill the guest details
     sub fill_list_details {
-        &addrow_log("Fetching extended guest details...");
+        my $gref = &getsel_list_guest();
+        &addrow_msg_log("Retrieving extended guest details for $$gref{Name}");
         my $vhost = &vhost();
         $gui{treestoreDetails}->clear();
-        my $treemodel = $gui{treeviewDetails}->get_model();
-        my $gref = &getsel_list_guest();
         my $IVRDEServer = IMachine_getVRDEServer($$gref{IMachine});
         my @IStorageController = IMachine_getStorageControllers($$gref{IMachine});
         my $IAudioAdapter = IMachine_getAudioAdapter($$gref{IMachine});
@@ -57,7 +52,7 @@ our (%gui, %vmc, %signal, %prefs);
         my $geniter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatGen}, 'General', 800, 0.0, 'EXPANDDETGEN']);
         &addrow_details($geniter, [1, 2], [' Name:', $$gref{Name}]);
         &addrow_details($geniter, [1, 2], [' Operating System:', IMachine_getOSTypeId($$gref{IMachine})]);
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($geniter), 1) if ($prefs{EXPANDDETGEN});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($geniter), 1) if ($prefs{EXPANDDETGEN});
 
         my $sysiter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatSys}, 'System', 800, 0.0, 'EXPANDDETSYS']);
         my $mem = IMachine_getMemorySize($$gref{IMachine});
@@ -82,7 +77,7 @@ our (%gui, %vmc, %signal, %prefs);
         $vtx ? &addrow_details($sysiter, [1, 2], [' Acceleration:', $vtx]) : &addrow_details($sysiter, [1, 2], [' Acceleration:', '<None Enabled>']);
         my $paravirt = 'Configured: ' . IMachine_getParavirtProvider($$gref{IMachine}) . ', Effective: ' . IMachine_getEffectiveParavirtProvider($$gref{IMachine});
         &addrow_details($sysiter, [1, 2], [' Paravirtualization:', $paravirt]);
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($sysiter), 1) if ($prefs{EXPANDDETSYS});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($sysiter), 1) if ($prefs{EXPANDDETSYS});
 
         my $dispiter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatDisp}, 'Display', 800, 0.0, 'EXPANDDETDISP']);
         &addrow_details($dispiter, [1, 2], [' Video Memory:', IGraphicsAdapter_getVRAMSize($IGraphicsAdapter) . ' MB']);
@@ -93,7 +88,7 @@ our (%gui, %vmc, %signal, %prefs);
         $vidaccel ? &addrow_details($dispiter, [1, 2], [' Acceleration:', $vidaccel]) : &addrow_details($dispiter, [1, 2], [' Acceleration:', '<None Enabled>']);
         IVRDEServer_getEnabled($IVRDEServer) eq 'true' ? &addrow_details($dispiter, [1, 2], [' Remote Display Ports:', IVRDEServer_getVRDEProperty($IVRDEServer, 'TCP/Ports')])
                                                     : &addrow_details($dispiter, [1, 2], [' Remote Display Ports:', '<Remote Display Disabled>']);
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($dispiter), 1) if ($prefs{EXPANDDETDISP});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($dispiter), 1) if ($prefs{EXPANDDETDISP});
 
         my $storiter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatStor}, 'Storage', 800, 0.0, 'EXPANDDETSTOR']);
         foreach my $controller (@IStorageController) {
@@ -111,13 +106,13 @@ our (%gui, %vmc, %signal, %prefs);
             }
         }
 
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($storiter), 1) if ($prefs{EXPANDDETSTOR});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($storiter), 1) if ($prefs{EXPANDDETSTOR});
 
         my $audioiter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatAudio}, 'Audio', 800, 0.0, 'EXPANDDETAUDIO']);
         IAudioAdapter_getEnabled($IAudioAdapter) eq 'true' ? (&addrow_details($audioiter, [1, 2], [' Host Driver:', IAudioAdapter_getAudioDriver($IAudioAdapter)])
                                                         and &addrow_details($audioiter, [1, 2], [' Controller:', IAudioAdapter_getAudioController($IAudioAdapter)]))
                                                         : &addrow_details($audioiter, 1, ' <Audio Disabled>');
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($audioiter), 1) if ($prefs{EXPANDDETAUDIO});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($audioiter), 1) if ($prefs{EXPANDDETAUDIO});
 
         my $netiter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatNet}, 'Network', 800, 0.0, 'EXPANDDETNET']);
         foreach (0..($$vhost{maxnet}-1)) {
@@ -136,7 +131,7 @@ our (%gui, %vmc, %signal, %prefs);
             }
         }
 
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($netiter), 1) if ($prefs{EXPANDDETNET});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($netiter), 1) if ($prefs{EXPANDDETNET});
 
         my $ioiter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatIO}, 'I/O Ports', 800, 0.0, 'EXPANDDETIO']);
         foreach (0..($$vhost{maxser}-1)) {
@@ -150,7 +145,7 @@ our (%gui, %vmc, %signal, %prefs);
         my $IParallelPort = IMachine_getParallelPort($$gref{IMachine}, 0);
         IParallelPort_getEnabled($IParallelPort) eq 'true' ? &addrow_details($ioiter, [1, 2], [' LPT Port:', 'Enabled  ' . IParallelPort_getPath($IParallelPort)])
                                                         : &addrow_details($ioiter, [1, 2], [' LPT Port:', 'Disabled']);
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($ioiter), 1) if ($prefs{EXPANDDETIO});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($ioiter), 1) if ($prefs{EXPANDDETIO});
 
         my $usbiter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatUSB}, 'USB', 800, 0.0, 'EXPANDDETUSB']);
         if (@IUSBController) {
@@ -166,12 +161,12 @@ our (%gui, %vmc, %signal, %prefs);
             &addrow_details($usbiter, [1, 2], ['  Device Filters:', scalar(@filters) . " ($active active)"]);
         }
         else { &addrow_details($usbiter, 1, ' <None Enabled>'); }
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($usbiter), 1) if ($prefs{EXPANDDETUSB});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($usbiter), 1) if ($prefs{EXPANDDETUSB});
 
         my $shareiter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatShare}, 'Shared Folders', 800, 0.0, 'EXPANDDETSHARE']);
         my @sf = IMachine_getSharedFolders($$gref{IMachine});
         &addrow_details($shareiter, [1, 2], [' Shared Folders:', scalar(@sf)]);
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($shareiter), 1) if ($prefs{EXPANDDETSHARE});
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($shareiter), 1) if ($prefs{EXPANDDETSHARE});
 
         my $sref = &get_session($$gref{IMachine});
 
@@ -182,23 +177,20 @@ our (%gui, %vmc, %signal, %prefs);
             my $additionsversion = IGuest_getAdditionsVersion($IGuest);
             if ($additionsversion) { &addrow_details($runiter, [1, 2], [' Guest Additions:', $additionsversion]); }
             else { &addrow_details($runiter, [1, 2], [' Guest Additions:', 'Not Installed (or not running)']); }
-            $gui{treeviewDetails}->expand_row($treemodel->get_path($runiter), 1) if ($prefs{EXPANDDETRUN});
+            $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($runiter), 1) if ($prefs{EXPANDDETRUN});
         }
 
         ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 
         my $desciter = &addrow_details(undef, [0, 1, 3, 4, 5], [$gui{img}{CatDesc}, 'Description', 800, 0.0, 'EXPANDDETDESC']);
         my $desc = IMachine_getDescription($$gref{IMachine});
-        $desc ? &addrow_details($desciter, [1, 2], [' Description:', $desc])
-            : &addrow_details($desciter, 1, ' <None>');
-        $gui{treeviewDetails}->expand_row($treemodel->get_path($desciter), 1) if ($prefs{EXPANDDETDESC});
-
-        &addrow_log("Extended guest details retrieved.");
+        $desc ? &addrow_details($desciter, [1, 2], [' Description:', $desc]) : &addrow_details($desciter, 1, ' <None>');
+        $gui{treeviewDetails}->expand_row($gui{treestoreDetails}->get_path($desciter), 1) if ($prefs{EXPANDDETDESC});
+        &addrow_msg_log("Extended guest details retrieved for $$gref{Name}");
     }
 }
 
-
-# Adds a line to the details view
+# Adds a row to the details view
 sub addrow_details {
     my ($iter, $cols, $vals) = @_;
     my $citer = $gui{treestoreDetails}->append($iter);
@@ -209,7 +201,6 @@ sub addrow_details {
 # Generic routine for clearing lists that need the signal disabled
 sub clr_list_generic {
     my ($treeview, $signal) = @_;
-
     my $liststore = $treeview->get_model();
     $treeview->signal_handler_block($signal) if ($treeview);
     $liststore->clear();
@@ -217,7 +208,7 @@ sub clr_list_generic {
 }
 
 # Fills the remote file chooser with a list of files. Involves a lot of splicing because
-# of the crazy way VirtualBox returns a file list
+# of the bizarre way VirtualBox returns a file list
 sub fill_list_remotefiles {
     &set_pointer($gui{dialogRemoteFileChooser}, 'watch');
     my ($location, $filter) = @_;
@@ -247,7 +238,6 @@ sub fill_list_remotefiles {
         $gui{liststoreRemoteFileChooser}->set($iter, [0, 1, 2, 3, 4], ['(Parent)', '..', '', '', $gui{img}{ParentIcon}]);
 
         foreach my $fname (sort { lc($a) cmp lc($b) } (keys %files)) {
-
             if ($files{$fname}{type} == 4) { # Always add in directories
                 my $iter = $gui{liststoreRemoteFileChooser}->append();
                 $gui{liststoreRemoteFileChooser}->set($iter, [0, 1, 2, 3, 4], ['(Dir)', $fname, $files{$fname}{size}, $files{$fname}{mode}, $gui{img}{DirIcon}]);
@@ -280,13 +270,12 @@ sub fill_list_log {
     $gui{liststoreLog3}->clear();
 
     for my $lognum (0..3) {
-        my $log;
-        my $offset = 0;
+        my ($offset, $log) = 0;
 
         if (IMachine_queryLogFilename($IMachine, $lognum)) {
             # Reading logs is limited to a maximum chunk size - normally 32K. The chunks are base64 encoded so we
-            # need to read a chunk, decode, calculate next offset. Limit loop to 40 runs (max 1MB retrieval)
-            for (1..40) {
+            # need to read a chunk, decode, calculate next offset. Limit loop to 80 runs (max 2MB retrieval)
+            for (1..80) {
                 my $rawlog = IMachine_readLog($IMachine, $lognum, $offset, 32768); # Request 32K max. Limit is usually 32K anyway
                 last if (!$rawlog); # Terminate loop if we've reached the end or log is empty
                 $log .= decode_base64($rawlog); # Rawlog is base64 encoded. Append to log
@@ -294,10 +283,10 @@ sub fill_list_log {
             }
 
             if ($log) {
-                my @logarr = split "\n", $log; # Do we need to include windows/mac EOL here?
+                my @logarr = split "\n", $log;
 
                 foreach (0..$#logarr) {
-                    $logarr[$_] =~ s/\r//g;
+                    $logarr[$_] =~ s/\r//g; # Strip any carriage returns
                     my $iter = $gui{'liststoreLog' . $lognum}->append;
                     $gui{'liststoreLog' . $lognum}->set($iter, [0, 1], ["$_: ", $logarr[$_]]);
                 }
@@ -320,22 +309,22 @@ sub fill_list_serverinfo {
     $gui{liststoreInfo}->clear();
     my $vhost = &vhost();
     &addrow_info([0, 1], ['URL:', $endpoint]);
-    &addrow_info([0, 1], ['VirtualBox Version:', $$vhost{vbver}]);
+    &addrow_info([0, 1], ['VirtualBox Version:', IVirtualBox_getVersion($gui{websn})]);
     $$vhost{vrdeextpack} ? &addrow_info([0, 1], ['Extension Pack:', $$vhost{vrdeextpack}]) : &addrow_info([0, 1], ['Extension Pack:', '<None>']);
-    &addrow_info([0, 1], ['Build Revision:', $$vhost{buildrev}]);
-    &addrow_info([0, 1], ['Package Type:', $$vhost{pkgtype}]);
-    &addrow_info([0, 1], ['Global Settings File:', $$vhost{settingsfile}]);
+    &addrow_info([0, 1], ['Build Revision:', IVirtualBox_getRevision($gui{websn})]);
+    &addrow_info([0, 1], ['Package Type:', IVirtualBox_getPackageType($gui{websn})]);
+    &addrow_info([0, 1], ['Global Settings File:', IVirtualBox_getSettingsFilePath($gui{websn})]);
     &addrow_info([0, 1], ['Machine Folder:', $$vhost{machinedir}]);
     &addrow_info([0, 1], ['Server Logical CPUs:', $$vhost{maxhostcpuon}]);
-    &addrow_info([0, 1], ['Server CPU Type:', $$vhost{cpudesc}]);
-    &addrow_info([0, 1], ['Server CPU Speed:', "$$vhost{cpuspeed} Mhz (approx)"]);
-    &addrow_info([0, 1], ['VT-x/AMD-V Support:', "$$vhost{vtx}"]);
+    &addrow_info([0, 1], ['Server CPU Type:', IHost_getProcessorDescription($$vhost{IHost})]);
+    &addrow_info([0, 1], ['Server CPU Speed:', IHost_getProcessorSpeed($$vhost{IHost}) . " Mhz (approx)"]);
+    &addrow_info([0, 1], ['VT-x/AMD-V Support:', IHost_getProcessorFeature($$vhost{IHost}, 'HWVirtEx')]);
     &addrow_info([0, 1], ['VT-x/AMD-V Exclusive:', $$vhost{hwexclusive}]);
-    &addrow_info([0, 1], ['PAE Support:', "$$vhost{pae}"]);
+    &addrow_info([0, 1], ['PAE Support:', IHost_getProcessorFeature($$vhost{IHost}, 'PAE')]);
     &addrow_info([0, 1], ['Server Memory Size:', "$$vhost{memsize} MB"]);
     &addrow_info([0, 1], ['Server OS:', $$vhost{os}]);
-    &addrow_info([0, 1], ['Server OS Version:', $$vhost{osver}]);
-    &addrow_info([0, 1], ['Default Audio:', $$vhost{defaudio}]);
+    &addrow_info([0, 1], ['Server OS Version:', IHost_getOSVersion($$vhost{IHost})]);
+    &addrow_info([0, 1], ['Default Audio:', ISystemProperties_getDefaultAudioDriver($$vhost{ISystemProperties})]);
     &addrow_info([0, 1], ['Min Guest RAM:', "$$vhost{minguestram} MB"]);
     &addrow_info([0, 1], ['Max Guest RAM:', &bytesToX($$vhost{maxguestram} * 1048576)]);
     &addrow_info([0, 1], ['Min Guest Video RAM:', "$$vhost{minguestvram} MB"]);
@@ -462,9 +451,8 @@ sub fill_list_editstorage {
     }
 
     sub onsel_list_vbprefsnat {
-        my $model = $gui{treeviewVBPrefsNAT}->get_model();
-        my $iter = $gui{treeviewVBPrefsNAT}->get_selection->get_selected() ? $gui{treeviewVBPrefsNAT}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($liststore, $iter) = $gui{treeviewVBPrefsNAT}->get_selection->get_selected();
+        my @row = $liststore->get($iter) if (defined($iter) and $liststore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach('Enabled', 'Name', 'INATNetwork');
         $gui{buttonVBPrefsDelNAT}->set_sensitive(1);
         $gui{buttonVBPrefsEditNAT}->set_sensitive(1);
@@ -500,25 +488,24 @@ sub fill_list_editstorage {
     }
 
     sub onsel_list_vbprefshon {
-        my $model = $gui{treeviewVBPrefsHON}->get_model();
-        my $iter =  $gui{treeviewVBPrefsHON}->get_selection->get_selected() ? $gui{treeviewVBPrefsHON}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($liststore, $iter) =  $gui{treeviewVBPrefsHON}->get_selection->get_selected();
+        my @row = $liststore->get($iter) if (defined($iter) and $liststore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach ('Name', 'IHostNetworkInterface', 'Uuid');
         $gui{buttonVBPrefsDelHON}->set_sensitive(1);
         $gui{buttonVBPrefsEditHON}->set_sensitive(1);
     }
 }
 
-# Adds a message to message log and scrolls to bottom
-sub addrow_log {
-    my ($msg) = @_;
-    my $iter = $gui{liststoreLog}->append;
-    my ($sec,$min,$hour,$mday,$mon,$year) = localtime();
-    $mon += 1;
-    $year += 1900;
-    $msg = sprintf("%d-%02d-%02d %02d:%02d:%02d    %s", $year, $mon, $mday, $hour, $min, $sec, $msg);
-    $gui{liststoreLog}->set($iter, [0], [$msg]);
-    $gui{treeviewLog}->scroll_to_cell($gui{treeviewLog}->get_model->get_path($iter), $gui{treeviewLog}->get_column(0), 1, 1.0, 1.0);
+# Adds entries to the message log and scrolls to bottom
+sub addrow_msg_log {
+    foreach my $msg (@_) {
+        my $iter = $gui{liststoreMsgLog}->append();
+        my ($sec,$min,$hour,$mday,$mon,$year) = localtime();
+        $mon += 1;
+        $year += 1900;
+        $gui{liststoreMsgLog}->set($iter, [0], [sprintf("%d-%02d-%02d %02d:%02d:%02d    %s", $year, $mon, $mday, $hour, $min, $sec, $msg)]);
+        $gui{treeviewMsgLog}->scroll_to_cell($gui{treeviewMsgLog}->get_model->get_path($iter), $gui{treeviewMsgLog}->get_column(0), 1, 1.0, 1.0);
+    }
 }
 
 # Adds a row to the editshared list
@@ -554,7 +541,7 @@ sub getsel_combo {
     my $model = $widget->get_model();
     my $iter = $widget->get_active_iter();
     $col = 0 if !defined($col);
-    $returnval = $model->get($iter, $col) if ($model->iter_is_valid($iter));
+    $returnval = $model->get($iter, $col) if (defined($iter) and $model->iter_is_valid($iter));
     return $returnval;
 }
 
@@ -595,26 +582,28 @@ sub getsel_list_remotefiles {
     return \@filearray;
 }
 
+# Gets a selected item in the shared folder list
 sub getsel_list_editshared {
-    my $model = $gui{treeviewEditShared}->get_model();
-    my ($path) = $gui{treeviewEditShared}->get_cursor();
-    my $iter = $gui{treeviewEditShared}->get_selection->get_selected() ? $model->get_iter($path) : $model->get_iter_first();
-    return undef if (!$iter);
-    my @row = $model->get($iter);
-    my %hash;
-    $hash{$_} = shift @row foreach ('Name', 'Folder', 'Access', 'Mount', 'Accessible', 'Tooltip', 'Permanent');
-    return \%hash;
+    my ($liststore, $iter) = $gui{treeviewEditShared}->get_selection->get_selected();
+
+    if (defined($iter) and $liststore->iter_is_valid($iter)) {
+        my @row = $liststore->get($iter);
+        my %hash;
+        $hash{$_} = shift @row foreach ('Name', 'Folder', 'Access', 'Mount', 'Accessible', 'Tooltip', 'Permanent');
+        return \%hash;
+    }
 }
 
+# Gets a selection from the Edit Storage List
 sub getsel_list_editstorage {
-    my $model = $gui{treeviewEditStor}->get_model();
-    my ($path) = $gui{treeviewEditStor}->get_cursor();
-    my $iter = $gui{treeviewEditStor}->get_selection->get_selected() ? $model->get_iter($path) : $model->get_iter_first();
-    return undef if (!$iter);
-    my @row = $model->get($iter);
-    my %hash;
-    $hash{$_} = shift @row foreach ('DisplayName', 'DisplayType', 'Tooltip', 'IsController', 'Bus', 'ControllerName', 'IMedium', 'IStorageController', 'MediumType', 'Device', 'Port', 'Location', 'Icon');
-    return \%hash;
+    my ($treestore, $iter) = $gui{treeviewEditStor}->get_selection->get_selected();
+
+    if (defined($iter) and $treestore->iter_is_valid($iter)) {
+        my @row = $treestore->get($iter);
+        my %hash;
+        $hash{$_} = shift @row foreach ('DisplayName', 'DisplayType', 'Tooltip', 'IsController', 'Bus', 'ControllerName', 'IMedium', 'IStorageController', 'MediumType', 'Device', 'Port', 'Location', 'Icon');
+        return \%hash;
+    }
 }
 
 # USB Filter List Handling
@@ -623,10 +612,10 @@ sub getsel_list_editstorage {
 
     sub getsel_list_usbfilters { return \%selected; }
 
+    # On selection of a USB filter
     sub onsel_list_usbfilters {
-        my $model = $gui{treeviewEditUSBFilters}->get_model();
-        my $iter = $gui{treeviewEditUSBFilters}->get_selection->get_selected() ? $gui{treeviewEditUSBFilters}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($liststore, $iter) = $gui{treeviewEditUSBFilters}->get_selection->get_selected();
+        my @row = $liststore->get($iter) if (defined($iter) and $liststore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach ('Enabled', 'IUSBDeviceFilter', 'Name', 'Position');
         $gui{buttonEditUSBEdit}->set_sensitive(1);
         $gui{buttonEditUSBRemove}->set_sensitive(1);
@@ -634,6 +623,7 @@ sub getsel_list_editstorage {
         $gui{buttonEditUSBDown}->set_sensitive(1);
     }
 
+    # Fill the USB filter list
     sub fill_list_usbfilters {
         &set_pointer($gui{dialogEdit}, 'watch');
         my ($IMachine) = @_;
@@ -907,10 +897,10 @@ sub onsel_list_editstorage {
         &set_pointer($gui{dialogVMM});
     }
 
+    # On selection of a floppy image in the list
     sub onsel_list_vmmfloppy {
-        my $model = $gui{treeviewVMMFloppy}->get_model();
-        my $iter = $gui{treeviewVMMFloppy}->get_selection->get_selected() ? $gui{treeviewVMMFloppy}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($treestore, $iter) = $gui{treeviewVMMFloppy}->get_selection->get_selected();
+        my @row = $treestore->get($iter) if (defined($iter) and $treestore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach ('Name', 'IMedium', 'Size', 'Accessible', 'Tooltip', 'Location', 'Type');
         $gui{toolbuttonVMMCopy}->set_sensitive(1);
         $gui{toolbuttonVMMMove}->set_sensitive(1);
@@ -1007,10 +997,10 @@ sub onsel_list_editstorage {
         &set_pointer($gui{dialogVMM});
     }
 
+    # On selection of a DVD image in the list
     sub onsel_list_vmmdvd {
-        my $model = $gui{treeviewVMMDVD}->get_model();
-        my $iter = $gui{treeviewVMMDVD}->get_selection->get_selected() ? $gui{treeviewVMMDVD}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($treestore, $iter) = $gui{treeviewVMMDVD}->get_selection->get_selected();
+        my @row = $treestore->get($iter) if (defined($iter) and $treestore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach ('Name', 'IMedium', 'Size', 'Accessible', 'Tooltip', 'Location', 'Type');
         $gui{toolbuttonVMMCopy}->set_sensitive(0);
         $gui{toolbuttonVMMMove}->set_sensitive(1);
@@ -1085,9 +1075,8 @@ sub onsel_list_editstorage {
     }
 
     sub onsel_list_pf4 {
-        my $model = $gui{treeviewPFRulesIPv4}->get_model();
-        my $iter = $gui{treeviewPFRulesIPv4}->get_selection->get_selected() ? $gui{treeviewPFRulesIPv4}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($liststore, $iter) = $gui{treeviewPFRulesIPv4}->get_selection->get_selected();
+        my @row = $liststore->get($iter) if (defined($iter) and $liststore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach ('Name', 'Protocol', 'HostIP', 'HostPort', 'GuestIP', 'GuestPort', 'INATNetwork');
         $gui{buttonPFRulesRemove4}->set_sensitive(1);
     }
@@ -1125,9 +1114,8 @@ sub onsel_list_editstorage {
     }
 
     sub onsel_list_pf6 {
-        my $model = $gui{treeviewPFRulesIPv6}->get_model();
-        my $iter = $gui{treeviewPFRulesIPv6}->get_selection->get_selected() ? $gui{treeviewPFRulesIPv6}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($liststore, $iter) = $gui{treeviewPFRulesIPv6}->get_selection->get_selected();
+        my @row = $liststore->get($iter) if (defined($iter) and $liststore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach ('Name', 'Protocol', 'HostIP', 'HostPort', 'GuestIP', 'GuestPort', 'INATNetwork');
         $gui{buttonPFRulesRemove6}->set_sensitive(1);
     }
@@ -1152,10 +1140,10 @@ sub onsel_list_editstorage {
         &set_pointer($gui{dialogVMM});
     }
 
+    # On selection of a hard disk image in the list
     sub onsel_list_vmmhd {
-        my $model = $gui{treeviewVMMHD}->get_model();
-        my $iter = $gui{treeviewVMMHD}->get_selection->get_selected() ? $gui{treeviewVMMHD}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($treestore, $iter) = $gui{treeviewVMMHD}->get_selection->get_selected();
+        my @row = $treestore->get($iter) if (defined($treestore) and $treestore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach ('Name', 'IMedium', 'Asize', 'Vsize', 'Accessible', 'Tooltip', 'Location', 'Type', 'LsizeInt');
         $gui{toolbuttonVMMCopy}->set_sensitive(1);
         $gui{toolbuttonVMMMove}->set_sensitive(1);
@@ -1289,12 +1277,12 @@ sub onsel_list_shared {
 
     sub getsel_list_snapshots { return \%selected; }
 
-    # Set sensitivity when a snapshot is selected
+    # On selection of a snapshot in the list
     sub onsel_list_snapshots {
-        my $model = $gui{treeviewSnapshots}->get_model();
-        my $iter = $gui{treeviewSnapshots}->get_selection->get_selected() ? $gui{treeviewSnapshots}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($treestore, $iter) = $gui{treeviewSnapshots}->get_selection->get_selected();
+        my @row = $treestore->get($iter) if (defined($iter) and $treestore->iter_is_valid($iter));
         $selected{$_} = shift @row foreach ('Name', 'Date', 'ISnapshot', 'Icon');
+
         if ($selected{ISnapshot}) {
             $gui{buttonRestoreSnapshot}->set_sensitive(1);
             $gui{buttonDeleteSnapshot}->set_sensitive(1);
@@ -1313,7 +1301,7 @@ sub onsel_list_shared {
 
     sub fill_list_snapshots {
         my $gref = &getsel_list_guest();
-        &addrow_log("Fetching snapshots for $$gref{Name}...");
+        &addrow_msg_log("Retrieving snapshots for $$gref{Name}");
         &clr_list_snapshots();
 
         if (IMachine_getSnapshotCount($$gref{IMachine}) > 0) {
@@ -1323,7 +1311,7 @@ sub onsel_list_shared {
             $gui{treeviewSnapshots}->expand_all();
         }
 
-        &addrow_log('Snapshot fetch complete');
+        &addrow_msg_log("Retrieved snapshots for $$gref{Name}");
     }
 
     # Clear snapshot list and set sensitivity
@@ -1359,17 +1347,18 @@ sub onsel_list_shared {
 
 # Guest List Handling
 {
-    my %selected = (Uuid => 'None'); # Initialize this element as it may be tested before the hash is fully initialized
+    my %selected = (Uuid           => 'None',
+                    vscrollbar_pos => 0); # Initialize this element as it may be tested before the hash is fully initialized
 
     sub makesel_list_guest { $selected{Uuid} = $_[0]; }
 
     sub getsel_list_guest { return \%selected; }
 
+    # On selection of a guest in the list
     sub onsel_list_guest {
         &set_pointer($gui{windowMain}, 'watch');
-        my $model = $gui{treeviewGuest}->get_model();
-        my $iter = $gui{treeviewGuest}->get_selection->get_selected() ? $gui{treeviewGuest}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
+        my ($treestore, $iter) = $gui{treeviewGuest}->get_selection->get_selected();
+        my @row = $treestore->get($iter) if (defined($iter) and $treestore->iter_is_valid($iter));
 
         # If there's no IMachine, it's a group so don't waste anymore time
         if (!$row[2]) {
@@ -1479,7 +1468,7 @@ sub onsel_list_shared {
     sub fill_list_guest {
         my $osver = &osver();
         my %grouptree;
-        &addrow_log("Fetching guest list from $endpoint...");
+        &addrow_msg_log("Retrieving guest list from $endpoint");
         &set_pointer($gui{windowMain}, 'watch');
         &clr_list_guest();
         my %guestlist;
@@ -1543,13 +1532,19 @@ sub onsel_list_shared {
                 &onsel_list_guest();
         }
 
+        # Move the scrollbar to the position we were at before refreshing the list
+        $gui{scrolledGuest}->get_vadjustment()->set_value($selected{vscrollbar_pos});
+
         &set_pointer($gui{windowMain});
-        &addrow_log('Guest list complete');
-        &addrow_log('WARNING: You have one or more guests that are inaccessible and have been excluded from ' .
-                    'the guest list. You must use vboxmanage or VirtualBox on the server to fix these issues') if ($inaccessible);
+        &addrow_msg_log("Retrieved guest list from $endpoint");
+        &addrow_msg_log('Warning: You have one or more guests that are inaccessible and have been excluded from ' .
+                        'the guest list. You must use vboxmanage or VirtualBox on the server to fix these issues') if ($inaccessible);
     }
 
+    # Clear the guest list and snapshots
     sub clr_list_guest {
+        # Record the vertical scrollbar position for restoring later
+        $selected{vscrollbar_pos} = $gui{scrolledGuest}->get_vadjustment()->get_value();
         &sens_unselected();
         $gui{treeviewGuest}->signal_handler_block($signal{treeviewGuest_cursorChanged});
         $gui{treestoreGuest}->clear();
@@ -1566,7 +1561,7 @@ sub onsel_list_shared {
     # If pname exists we're calling this method directly, otherwise we're calling it from the button
     sub addrow_profile {
         my ($widget, $pname, $url, $username, $password) = @_;
-        my $iter = $gui{liststoreProfiles}->append;
+        my $iter = $gui{liststoreProfiles}->append();
 
         if ($pname) { $gui{liststoreProfiles}->set($iter, [0, 1, 2, 3], [$pname, $url, $username, $password]); }
         else {
@@ -1579,70 +1574,70 @@ sub onsel_list_shared {
 
     sub getsel_list_profile { return \%selected; }
 
+    # On selection of a profile in the list
     sub onsel_list_profile {
-        my $model = $gui{treeviewConnectionProfiles}->get_model();
-        my $iter = $gui{treeviewConnectionProfiles}->get_selection->get_selected() ? $gui{treeviewConnectionProfiles}->get_selection->get_selected() : $model->get_iter_first();
-        my @row = $model->get($iter);
-        $selected{$_} = shift @row foreach ('Name', 'URL', 'Username', 'Password');
-        $gui{entryPrefsConnectionProfileName}->set_text($selected{Name});
-        $gui{entryPrefsConnectionProfileURL}->set_text($selected{URL});
-        $gui{entryPrefsConnectionProfileUsername}->set_text($selected{Username});
-        $gui{entryPrefsConnectionProfilePassword}->set_text($selected{Password});
-        $gui{checkbuttonConnectionProfileAutoConnect}->set_active(1) if ($selected{Name} eq $prefs{AUTOCONNPROF});
-        $gui{checkbuttonConnectionProfileAutoConnect}->set_active(0) if ($selected{Name} ne $prefs{AUTOCONNPROF});
-        $gui{buttonPrefsConnectionProfileDelete}->set_sensitive(1);
-        $gui{tablePrefsProfile}->set_sensitive(1);
+        my ($liststore, $iter) = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
+
+        if (defined($iter) and $liststore->iter_is_valid($iter)) {
+            my @row = $liststore->get($iter);
+            $selected{$_} = shift @row foreach ('Name', 'URL', 'Username', 'Password');
+            $gui{entryPrefsConnectionProfileName}->set_text($selected{Name});
+            $gui{entryPrefsConnectionProfileURL}->set_text($selected{URL});
+            $gui{entryPrefsConnectionProfileUsername}->set_text($selected{Username});
+            $gui{entryPrefsConnectionProfilePassword}->set_text($selected{Password});
+            $gui{checkbuttonConnectionProfileAutoConnect}->set_active(1) if ($selected{Name} eq $prefs{AUTOCONNPROF});
+            $gui{checkbuttonConnectionProfileAutoConnect}->set_active(0) if ($selected{Name} ne $prefs{AUTOCONNPROF});
+            $gui{buttonPrefsConnectionProfileDelete}->set_sensitive(1);
+            $gui{tablePrefsProfile}->set_sensitive(1);
+        }
     }
 
     # Delete a connection profile
     sub remove_profile {
-        my ($widget) = @_;
-        my $model = $gui{treeviewConnectionProfiles}->get_model();
-        my $iter = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
-        my $nextiter = $model->iter_next($iter);
+        my ($liststore, $iter) = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
 
-        if ($gui{liststoreProfiles}->iter_is_valid($iter)) {
+        if (defined($iter) and $liststore->iter_is_valid($iter)) {
             $gui{entryPrefsConnectionProfileName}->set_text('');
             $gui{entryPrefsConnectionProfileURL}->set_text('');
             $gui{entryPrefsConnectionProfileUsername}->set_text('');
             $gui{entryPrefsConnectionProfilePassword}->set_text('');
-            $gui{liststoreProfiles}->remove($iter);
-            $gui{buttonPrefsConnectionProfileDelete}->set_sensitive(0);
-            $gui{tablePrefsProfile}->set_sensitive(0);
+            # Iter is automatically modified to point to the next row or none if it's not valid
+            $liststore->remove($iter);
         }
 
-        if ($nextiter) {
-            $gui{treeviewConnectionProfiles}->get_selection()->select_iter($nextiter);
-            &onsel_list_profile();
+        # If there are no items, desensitise
+        if ($liststore->iter_n_children() < 1) {
+            $gui{buttonPrefsConnectionProfileDelete}->set_sensitive(0);
+            $gui{tablePrefsProfile}->set_sensitive(0);
         }
     }
 
     sub profile_name_change {
-        my ($user, $iter) = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
+        my ($liststore, $iter) = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
         # Works around a perl-Gtk3 bug
         my $text = Glib::Object::Introspection::GValueWrapper->new('Glib::String', $gui{entryPrefsConnectionProfileName}->get_text());
-        $gui{liststoreProfiles}->set_value($iter, 0, $text) if ($iter);
+        $liststore->set_value($iter, 0, $text) if (defined($iter) and $liststore->iter_is_valid($iter));
     }
 
     sub profile_url_change {
-        my ($user, $iter)  = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
+        my ($liststore, $iter)  = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
         # Works around a perl-Gtk3 bug
         my $text = Glib::Object::Introspection::GValueWrapper->new('Glib::String', $gui{entryPrefsConnectionProfileURL}->get_text());
-        $gui{liststoreProfiles}->set_value($iter, 1, $text) if ($iter);
+        $liststore->set_value($iter, 1, $text) if (defined($iter) and $liststore->iter_is_valid($iter));
     }
 
     sub profile_username_change {
-        my ($user, $iter) = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
+        my ($liststore, $iter) = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
         # Works around a perl-Gtk3 bug
         my $text = Glib::Object::Introspection::GValueWrapper->new('Glib::String', $gui{entryPrefsConnectionProfileUsername}->get_text());
-        $gui{liststoreProfiles}->set_value($iter, 2, $text) if ($iter);
+        $liststore->set_value($iter, 2, $text) if (defined($iter) and $liststore->iter_is_valid($iter));
     }
 
     sub profile_password_change {
-        my ($user, $iter) = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
+        my ($liststore, $iter) = $gui{treeviewConnectionProfiles}->get_selection->get_selected();
         # Works around a perl-Gtk3 bug
         my $text = Glib::Object::Introspection::GValueWrapper->new('Glib::String', $gui{entryPrefsConnectionProfilePassword}->get_text());
-        $gui{liststoreProfiles}->set_value($iter, 3, $text) if ($iter);
+        $liststore->set_value($iter, 3, $text) if (defined($iter) and $liststore->iter_is_valid($iter));
     }
 
     sub profile_autoconn_change {
