@@ -78,7 +78,7 @@ sub show_dialog_new_guest {
 
                     IMachine_saveSettings($IMachine);
                     IVirtualBox_registerMachine($gui{websn}, $IMachine);
-                    &addrow_log("Created a new guest: $name");
+                    &addrow_msg_log("Created a new guest: $name");
 
                     if ($gui{checkbuttonNewNewHD}->get_active() == 1) {
                         my $sref = &get_session($IMachine);
@@ -237,14 +237,14 @@ sub create_new_clone {
     &show_progress_window($IProgress, 'Cloning Guest', $gui{img}{ProgressClone}) if ($IProgress); # MUST NOT USE $cloneIMachine until progress is complete, otherwise it waits
 
     if (IProgress_getCanceled($IProgress) eq 'true') {
-        &addrow_log("Cancelled creation of the clone $$cloneref{name}");
+        &addrow_msg_log("Cancelled creation of the clone $$cloneref{name}");
         IManagedObjectRef_release($cloneIMachine);
         $cloneIMachine = undef;
     }
     else {
         IMachine_saveSettings($cloneIMachine);
         IVirtualBox_registerMachine($gui{websn}, $cloneIMachine);
-        &addrow_log("Cloned $$srcgref{Name} to $$cloneref{name}");
+        &addrow_msg_log("Cloned $$srcgref{Name} to $$cloneref{name}");
     }
 }
 
@@ -258,7 +258,7 @@ sub create_new_dskimg_clone {
     &show_progress_window($IProgress, 'Copying or Cloning Disk Image', $gui{img}{ProgressMediaCreate});
 
     if (IProgress_getCanceled($IProgress) eq 'true') {
-        &addrow_log("Cancelled disk copy or cloning: $imgfile");
+        &addrow_msg_log("Cancelled disk copy or cloning: $imgfile");
         IManagedObjectRef_release($IMedium);
         $IMedium = undef;
     }
@@ -268,7 +268,7 @@ sub create_new_dskimg_clone {
         $IMedium = undef;
     }
     else {
-        &addrow_log("Copied or cloned disk image to new file: $imgfile");
+        &addrow_msg_log("Copied or cloned disk image to new file: $imgfile");
     }
 
     Gtk3::main_iteration while Gtk3::events_pending;
@@ -286,7 +286,7 @@ sub create_new_dskimg {
     &show_progress_window($IProgress, 'Creating Disk Image', $gui{img}{ProgressMediaCreate});
 
     if (IProgress_getCanceled($IProgress) eq 'true') {
-        &addrow_log("Cancelled disk image creation: $imgfile");
+        &addrow_msg_log("Cancelled disk image creation: $imgfile");
         IManagedObjectRef_release($IMedium);
         $IMedium = undef;
     }
@@ -296,7 +296,7 @@ sub create_new_dskimg {
         $IMedium = undef;
     }
     else {
-        &addrow_log("Created new disk image: $imgfile");
+        &addrow_msg_log("Created new disk image: $imgfile");
     }
 
     Gtk3::main_iteration while Gtk3::events_pending;
