@@ -76,48 +76,44 @@ sub rbprefs_save {
     mkdir($gui{PREFSDIR}, 0755) unless (-e $gui{PREFSDIR});
 
     if (open(PREFS, '>', $gui{CONFIGFILE})) {
-        foreach my $key (keys %prefs) {
+        foreach my $key (sort(keys %prefs)) {
             if ($key eq 'URL') {
                 foreach (keys %{$prefs{URL}}) { print PREFS "URL=$_\n"; }
             }
             elsif ($key eq 'USER') {
                 foreach (keys %{$prefs{USER}}) { print PREFS "USER=$_\n"; }
             }
-            else { print(PREFS "$key=$prefs{$key}\n"); }
+            else { print PREFS "$key=$prefs{$key}\n"; }
         }
         close(PREFS);
     }
     else { warn "Unable to save preferences: $gui{CONFIGFILE}\n"; }
-
-
 }
 
-# Saves the profiles.
-# DO NOT call this from rbprefs_save otherwise there will be a race condition which will
-# empty the profiles file.
+# Saves the profiles.DO NOT call this from rbprefs_save otherwise there will be
+# a race condition which will empty the profiles file.
 sub rbprofiles_save {
     # As this file might contain passwords, we'll create it 0600, but only if it's the first time we're creating it.
-    my $new = 1;
-    $new = 0 if (-e $gui{PROFILESFILE});
+    my $newprofilesfile = (-e $gui{PROFILESFILE}) ? 0 : 1;
 
     # Save the connection profiles
     if (open(PROFILES, '>', $gui{PROFILESFILE})) {
-        chmod(0600, $gui{PROFILESFILE}) if ($new);
+        chmod(0600, $gui{PROFILESFILE}) if ($newprofilesfile);
         my $iter = $gui{liststoreProfiles}->get_iter_first();
 
-        while($iter) {
-            print(PROFILES $gui{liststoreProfiles}->get_value($iter, 0) . "\a");
-            print(PROFILES $gui{liststoreProfiles}->get_value($iter, 1) . "\a");
-            print(PROFILES $gui{liststoreProfiles}->get_value($iter, 2) . "\a");
+        while(defined($iter) and $gui{liststoreProfiles}->iter_is_valid($iter)) {
+            print(PROFILES $gui{liststoreProfiles}->get_value($iter, 0) . "\a" .
+                           $gui{liststoreProfiles}->get_value($iter, 1) . "\a" .
+                           $gui{liststoreProfiles}->get_value($iter, 2) . "\a");
             my $password = $gui{liststoreProfiles}->get_value($iter, 3);
             my $key = &random_key(length($password));
             $password = &xor_pass($password, $key);
             my @ordpass = unpack("C*", $password);
             $password = join(' ', @ordpass);
-            print(PROFILES "$password\a");
-            print(PROFILES "$key\n");
-            $iter = $gui{liststoreProfiles}->iter_next($iter);
+            print PROFILES "$password\a$key\n";
+            $gui{liststoreProfiles}->iter_next($iter); # The iter is now modified directly
         }
+
         close(PROFILES);
     }
 }
@@ -126,7 +122,7 @@ sub rbprofiles_save {
 sub save_window_pos {
     my ($winname) = @_;
     my ($w, $h) = $gui{$winname}->get_size();
-    my ($x,$y) = $gui{$winname}->get_position();
+    my ($x, $y) = $gui{$winname}->get_position();
     $prefs{"WINPOS_$winname"} = "$w:$h:$x:$y";
     &rbprefs_save();
 }
@@ -138,8 +134,8 @@ sub show_dialog_editnat {
     $gui{checkbuttonvbprefsNATDHCP}->set_active(&bl(INATNetwork_getNeedDhcpServer($$natref{INATNetwork})));
     $gui{checkbuttonvbprefsNATipv6}->set_active(&bl(INATNetwork_getIPv6Enabled($$natref{INATNetwork})));
     $gui{checkbuttonvbprefsNATipv6route}->set_active(&bl(INATNetwork_getAdvertiseDefaultIPv6RouteEnabled($$natref{INATNetwork})));
-    #&fill_list_pf4($$natref{INATNetwork});
-    #&fill_list_pf6($$natref{INATNetwork});
+    &fill_list_pf4($$natref{INATNetwork});
+    &fill_list_pf6($$natref{INATNetwork});
 
     do {
         my $response = $gui{dialogNATDetails}->run;
