@@ -4,12 +4,12 @@ use warnings;
 our (%gui);
 
 sub show_dialog_vmm {
-    &addrow_log('Retrieving global media information...');
+    &addrow_msg_log('Retrieving global media information');
     &busy_window($gui{windowMain}, 0, 'watch');
     &fill_list_vmmhd();
     &fill_list_vmmdvd();
     &fill_list_vmmfloppy();
-    &addrow_log('Retrieved global media information.');
+    &addrow_msg_log('Retrieved global media information');
     &busy_window($gui{windowMain}, 0);
     $gui{dialogVMM}->run;
     $gui{dialogVMM}->hide;
@@ -20,8 +20,7 @@ sub vmm_tabchanged {
     my ($widget, $focus, $page) = @_;
     &vmm_sens_unselected(); # Reset widgets as they are evaluated later
 
-    #We need to re-evaluate selection on tab change
-    if ($page == 0) {
+    if ($page == 0) { # We need to re-evaluate selection on tab change
         $gui{toolbuttonVMMAdd}->set_icon_widget($gui{imageHDAdd32});
         $gui{toolbuttonVMMCreate}->set_icon_widget($gui{imageHDCreate32});
         $gui{toolbuttonVMMCreate}->set_sensitive(1);
@@ -93,7 +92,7 @@ sub vmm_release {
     }
 
     if ($warn == 1) { &show_err_msg('mediuminuse', "\nMedium: $$mediumref{Name}"); }
-    else { &addrow_log("Medium $$mediumref{Name} released."); }
+    else { &addrow_msg_log("Medium $$mediumref{Name} released."); }
 
     if ($page == 0) { &fill_list_vmmhd(); }
     elsif ($page == 1) { &fill_list_vmmdvd(); }
@@ -109,32 +108,32 @@ sub vmm_rem {
         $gui{dialogVMMRemoveDelete}->hide;
 
         if ($response eq '1') { # Deletes Disk (not cancellable)
-            # Use get state and not refresh state to ensure we have latest info
             my $MediumState = IMedium_refreshState($$hdref{IMedium});
+
             if ($MediumState eq 'Created' or $MediumState eq 'Inaccessible') {
                 my $IProgress = IMedium_deleteStorage($$hdref{IMedium});
                 &show_progress_window($IProgress, 'Deleting hard disk', $gui{img}{ProgressMediaDelete});
-                &addrow_log("Deleted hard disk $$hdref{Name}.");
+                &addrow_msg_log("Deleted hard disk $$hdref{Name}.");
                 &fill_list_vmmhd();
             }
             else { &show_err_msg('deletemedium', "\nMedium: $$hdref{Name}"); }
         }
         elsif ($response eq '2') { # Removes Disk
             IMedium_close($$hdref{IMedium});
-            &addrow_log("Storage $$hdref{Name} removed.");
+            &addrow_msg_log("Storage $$hdref{Name} removed");
             &fill_list_vmmhd();
         }
     }
     elsif ($page == 1) {
         my $dvdref = &getsel_list_vmmdvd();
         IMedium_close($$dvdref{IMedium});
-        &addrow_log("Storage $$dvdref{Name} removed.");
+        &addrow_msg_log("Storage $$dvdref{Name} removed");
         &fill_list_vmmdvd();
     }
     else {
         my $floppyref = &getsel_list_vmmfloppy();
         IMedium_close($$floppyref{IMedium});
-        &addrow_log("Storage $$floppyref{Name} removed.");
+        &addrow_msg_log("Storage $$floppyref{Name} removed");
         &fill_list_vmmfloppy();
     }
 }
@@ -146,7 +145,7 @@ sub vmm_compact {
     if ($MediumState eq 'Created') {
         my $IProgress = IMedium_compact($$hdref{IMedium});
         &show_progress_window($IProgress, 'Compacting hard disk', $gui{img}{ProgressMediaResize}) if ($IProgress);
-        &addrow_log("Compacted disk image $$hdref{Name}");
+        &addrow_msg_log("Compacted disk image $$hdref{Name}");
         &fill_list_vmmhd();
     }
     else { &show_err_msg('compactmedium', "\nMedium: $$hdref{Name}\nCurrent State: $MediumState"); }
@@ -182,7 +181,7 @@ sub vmm_add {
                 next if (!$hd->{FileName});
                 next if ($hd->{FileName} eq '..' or $hd->{Type} eq '(Dir)');
                 IVirtualBox_openMedium($gui{websn}, &rcatfile($location, $hd->{FileName}), 'HardDisk', 'ReadWrite', 0);
-                &addrow_log("Adding Hard Disk $hd->{FileName} to VMM");
+                &addrow_msg_log("Adding Hard Disk $hd->{FileName} to VMM");
             }
 
             &fill_list_vmmhd();
@@ -192,7 +191,7 @@ sub vmm_add {
                 next if (!$dvd->{FileName});
                 next if ($dvd->{FileName} eq '..' or $dvd->{Type} eq '(Dir)');
                 IVirtualBox_openMedium($gui{websn}, &rcatfile($location, $dvd->{FileName}), 'DVD', 'ReadOnly', 0);
-                &addrow_log("Adding DVD/CD $dvd->{FileName} to VMM");
+                &addrow_msg_log("Adding DVD/CD $dvd->{FileName} to VMM");
             }
 
             &fill_list_vmmdvd();
@@ -202,7 +201,7 @@ sub vmm_add {
                 next if (!$floppy->{FileName});
                 next if ($floppy->{FileName} eq '..' or $floppy->{Type} eq '(Dir)');
                 IVirtualBox_openMedium($gui{websn}, &rcatfile($location, $floppy->{FileName}), 'Floppy', 'ReadWrite', 0);
-                &addrow_log("Adding Floppy $floppy->{FileName} to VMM");
+                &addrow_msg_log("Adding Floppy $floppy->{FileName} to VMM");
             }
 
             &fill_list_vmmfloppy();
@@ -248,10 +247,8 @@ sub show_dialog_vmm_move {
 
     if ($response eq 'ok') {
         my $IProgress = IMedium_moveTo($$mediumref{IMedium}, $gui{entryMoveMediumTo}->get_text());
-
-        # Note: An $IProgress is not always returned for move operations are some are very quick
-        &show_progress_window($IProgress, 'Moving medium', $gui{img}{ProgressMediaMove}) if ($IProgress);
-        &addrow_log('Moved medium ' . $$mediumref{Location} . ' to ' . $gui{entryMoveMediumTo}->get_text());
+        &show_progress_window($IProgress, 'Moving medium', $gui{img}{ProgressMediaMove}) if ($IProgress); # Note: An $IProgress is not always returned for move operations are some are very quick
+        &addrow_msg_log('Moved medium ' . $$mediumref{Location} . ' to ' . $gui{entryMoveMediumTo}->get_text());
 
         if ($devicetype eq 'HardDisk') { &fill_list_vmmhd(); }
         elsif ($devicetype eq 'DVD') { &fill_list_vmmdvd(); }
@@ -264,33 +261,29 @@ sub show_dialog_vmm_modify {
     my $vhost = &vhost();
     my $hdref = &getsel_list_vmmhd();
     my $hdsizemb = ceil($$hdref{LsizeInt} / 1048576);
-    # Images cannot be shrunk, so pin the lowest value to the current disks size
-    $gui{spinbuttonVMMModifyResizeHD}->set_range($hdsizemb, $$vhost{maxhdsizemb});
+    $gui{spinbuttonVMMModifyResizeHD}->set_range($hdsizemb, $$vhost{maxhdsizemb}); # Images cannot be shrunk, so pin the lowest value to the current disks size
     $gui{spinbuttonVMMModifyResizeHD}->set_value($hdsizemb);
     $gui{entryVMMModifySource}->set_text($$hdref{Name});
     &combobox_set_active_text($gui{comboboxVMMModifyType}, $$hdref{Type}, 0);
-
     my $response = $gui{dialogVMMModify}->run;
     $gui{dialogVMMModify}->hide;
 
     if ($response eq 'ok') {
-        # Do any resize first because it may not be possible once the type has changed
-        my $newhdsizemb = $gui{spinbuttonVMMModifyResizeHD}->get_value_as_int();
+        my $newhdsizemb = $gui{spinbuttonVMMModifyResizeHD}->get_value_as_int(); # Do any resize first because it may not be possible once the type has changed
 
         if ($newhdsizemb > $hdsizemb and $gui{checkbuttonVMMModifyResizeHD}->get_active()) {
-            &addrow_log("Attempting to resize $$hdref{Name} ($hdsizemb MB -> $newhdsizemb MB)");
+            &addrow_msg_log("Resizing $$hdref{Name} ($hdsizemb MB -> $newhdsizemb MB)");
             my $IProgress = IMedium_resize($$hdref{IMedium}, ($newhdsizemb * 1048576));
             &show_progress_window($IProgress, 'Resizing Virtual Hard Disk Image', $gui{img}{ProgressMediaResize}) if ($IProgress);
-            # Check to see if it happened (not all types support resizing)
             my $MediumState = IMedium_refreshState($$hdref{IMedium}); # Make sure VB sees any size changes
             my $refreshsize = IMedium_getLogicalSize($$hdref{IMedium});
-            &show_err_msg('nohdresize', "\nMedium: $$hdref{Name}\nCurrent State: $MediumState") if (($refreshsize / 1048576) < $newhdsizemb);
+            &show_err_msg('nohdresize', "\nMedium: $$hdref{Name}\nCurrent State: $MediumState") if (($refreshsize / 1048576) < $newhdsizemb); # See if actually got resized, not all types support resizing
         }
 
         my $newtype = &getsel_combo($gui{comboboxVMMModifyType}, 0);
 
         if ($$hdref{Type} ne $newtype) {
-            &addrow_log("Attempting to modify image type of $$hdref{Name} ($$hdref{Type} -> $newtype)");
+            &addrow_msg_log("Modifying image type of $$hdref{Name} ($$hdref{Type} -> $newtype)");
             IMedium_setType($$hdref{IMedium}, $newtype) if ($$hdref{Type} ne $newtype);
         }
 
@@ -310,14 +303,13 @@ sub show_dialog_vmm_copy_hd {
     $gui{radiobuttonCopyHDDynamic}->set_active(1);
     $gui{radiobuttonCopyHDFixed}->set_sensitive(1);
     $gui{radiobuttonCopyHDSplit}->set_sensitive(0);
-
     my $response = $gui{dialogVMMCopyHD}->run;
     $gui{dialogVMMCopyHD}->hide();
 
     if ($response eq 'ok') {
         my ($vol, $dir, $file) = &rsplitpath($gui{entryCopyHDName}->get_text());
-
         my $variant = 'Standard'; # Standard is Dynamic
+
         if ($gui{radiobuttonCopyHDFixed}->get_active()) { $variant = 'Fixed'; }
         elsif ($gui{radiobuttonCopyHDSplit}->get_active()) { $variant = 'VmdkSplit2G'; }
 
@@ -327,7 +319,6 @@ sub show_dialog_vmm_copy_hd {
                          allocation => $variant,
                          imgformat  =>  &getsel_combo($gui{comboboxCopyHDFormat}, 1),
                          location   => $vol . $dir);
-
         my $srchdref = &getsel_list_vmmhd();
         &create_new_dskimg_clone(\%clonehd, $$srchdref{IMedium});
         &fill_list_vmmhd();
@@ -341,7 +332,6 @@ sub show_dialog_vmm_copy_floppy {
     $newfloppy =~ m/(.*)\.[^.]+$/; # Strip any extension
     $gui{entryVMMCopyFloppyName}->set_text($1 . '-copy-' . int(rand(999999)));
     $gui{entryVMMCopyFloppySource}->set_text($$fdref{Location});
-
     my $response = $gui{dialogVMMCopyFloppy}->run;
     $gui{dialogVMMCopyFloppy}->hide();
 
@@ -354,7 +344,6 @@ sub show_dialog_vmm_copy_floppy {
                            allocation => 'Standard',
                            imgformat  => 'raw',
                            location   => $vol . $dir);
-
             my $srcfdref = &getsel_list_vmmfloppy();
             &create_new_dskimg_clone(\%clonefd, $$srcfdref{IMedium});
             &fill_list_vmmfloppy();
@@ -401,7 +390,6 @@ sub vmm_sens_unselected {
 # Changes the sensitivity of resize widgets depending if the user selects that option
 sub vmm_modify_sens_resize {
     my ($widget) = @_;
-
     my $state = $widget->get_active();
     $gui{labelVMMModifyResizeHD}->set_sensitive($state);
     $gui{spinbuttonVMMModifyResizeHD}->set_sensitive($state);
